@@ -342,6 +342,7 @@ def core_load(usercore,mcores):
 ### convert to molecule ###
 ###########################
 def lig_load(userligand,licores):
+    
     globs = globalvars()
     ### get groups ###
     groups = []
@@ -371,10 +372,13 @@ def lig_load(userligand,licores):
             emsg = "We can't find the ligand structure file %s right now! Something is amiss. Exiting..\n" % flig
             print emsg
             return False, emsg
+        
         if ('.xyz' in flig):
             lig.OBmol = lig.getOBmol(flig,'xyzf')
+            
         elif ('.mol' in flig):
             lig.OBmol = lig.getOBmol(flig,'molf')
+            
         elif ('.smi' in flig):
             lig.OBmol = lig.getOBmol(flig,'smif')
             # generate coordinates if not existing
@@ -556,6 +560,7 @@ def plugin_defs():
 ###   file/folder name control   ###
 ####################################
 def get_name(args,rootdir,core,ligname,bind = False,bsmi = False):
+    ### DEPRECIATED, USE NAME_COMPLEX instead
     # reads in argument namespace
     # and chooses an appropriate name
     # bind_ident is used to pass binding
@@ -590,9 +595,6 @@ def get_name(args,rootdir,core,ligname,bind = False,bsmi = False):
 def name_complex(rootdir,core,ligs,ligoc,sernum,args,bind= False,bsmi=False):
     ## new version of the above, designed to 
     ## produce more human and machine-readable formats
-    #print('ligoc is ' + str(ligoc))
-    #print('lig is ' + str(ligs))
-    print(rootdir)
     romans={'I':'1','II':'2','III':'3','IV':'4','V':'5','VI':'6'}
     if args.name: # if set externerally
         name = rootdir+'/'+args.name
@@ -615,10 +617,12 @@ def name_complex(rootdir,core,ligs,ligoc,sernum,args,bind= False,bsmi=False):
         else:
             spin = "0"
         licores = getlicores()
+        sminum = 0
         for i,lig in enumerate(ligs):
             if not lig in licores:
                 lig = lig.split('\t')[0]
-                name += '_smi' + str(sernum+1) + '_' + str(ligoc[i])
+                sminum += 1
+                name += '_smi' +str(int(sernum)+int(sminum)) + '_' + str(ligoc[i])
             else:
                 name += '_' + str(lig) + '_' + str(ligoc[i])
         name += "_s_"+str(spin)
